==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/IPRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.IPRuleArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.Action
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * IP rule with specific IP or IP range in CIDR format.
 * @property action The action of IP ACL rule.
 * @property iPAddressOrRange Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
 */
public data class IPRuleArgs(
    public val action: Output<Action>? = null,
    public val iPAddressOrRange: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.IPRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.IPRuleArgs =
        com.pulumi.azurenative.storage.inputs.IPRuleArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .iPAddressOrRange(iPAddressOrRange.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPRuleArgs].
 */
@PulumiTagMarker
public class IPRuleArgsBuilder internal constructor() {
    private var action: Output<Action>? = null

    private var iPAddressOrRange: Output<String>? = null

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("cosobmnwlqltxjkp")
    public suspend fun action(`value`: Output<Action>) {
        this.action = value
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("methesutwgxfeaqb")
    public suspend fun iPAddressOrRange(`value`: Output<String>) {
        this.iPAddressOrRange = value
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("nyhpanryrxyavkmx")
    public suspend fun action(`value`: Action?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("dmxfhyuihdsrgodv")
    public suspend fun iPAddressOrRange(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iPAddressOrRange = mapped
    }

    internal fun build(): IPRuleArgs = IPRuleArgs(
        action = action,
        iPAddressOrRange = iPAddressOrRange ?: throw PulumiNullFieldException("iPAddressOrRange"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/IPRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.IPRuleArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.Action
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * IP rule with specific IP or IP range in CIDR format.
 * @property action The action of IP ACL rule.
 * @property iPAddressOrRange Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
 */
public data class IPRuleArgs(
    public val action: Output<Action>? = null,
    public val iPAddressOrRange: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.IPRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.IPRuleArgs =
        com.pulumi.azurenative.storage.inputs.IPRuleArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .iPAddressOrRange(iPAddressOrRange.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IPRuleArgs].
 */
@PulumiTagMarker
public class IPRuleArgsBuilder internal constructor() {
    private var action: Output<Action>? = null

    private var iPAddressOrRange: Output<String>? = null

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("jregwrcmgjkklqrt")
    public suspend fun action(`value`: Output<Action>) {
        this.action = value
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("twyehehnfvtylyue")
    public suspend fun iPAddressOrRange(`value`: Output<String>) {
        this.iPAddressOrRange = value
    }

    /**
     * @param value The action of IP ACL rule.
     */
    @JvmName("rgdakrnmagprtwnv")
    public suspend fun action(`value`: Action?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specifies the IP or IP range in CIDR format. Only IPV4 address is allowed.
     */
    @JvmName("vhcyrqrfvnirtuid")
    public suspend fun iPAddressOrRange(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iPAddressOrRange = mapped
    }

    internal fun build(): IPRuleArgs = IPRuleArgs(
        action = action,
        iPAddressOrRange = iPAddressOrRange ?: throw PulumiNullFieldException("iPAddressOrRange"),
    )
}
